<?php
/**
 * Popular options
 *
 * @package Theme Palace
 * @subpackage Yule
 * @since Yule 1.0.0
 */

// Add archive section
$wp_customize->add_section( 'yule_popular_section', array(
	'title'             => esc_html__( 'Popular','yule' ),
	'description'       => esc_html__( 'Popular section options.', 'yule' ),
	'panel'             => 'yule_front_page_panel',
) );

// Popular content enable control and setting
$wp_customize->add_setting( 'yule_theme_options[popular_section_enable]', array(
	'sanitize_callback' => 'yule_sanitize_switch_control',
	'default'          	=> $options['popular_section_enable'],
) );

$wp_customize->add_control( new Yule_Switch_Control( $wp_customize, 'yule_theme_options[popular_section_enable]', array(
	'label'             => esc_html__( 'Popular Section', 'yule' ),
	'section'           => 'yule_popular_section',
	'on_off_label' 		=> yule_switch_options(),
) ) );

// Popular content type control and setting
$wp_customize->add_setting( 'yule_theme_options[popular_content_type]', array(
	'sanitize_callback' => 'yule_sanitize_select',
	'default'          	=> $options['popular_content_type'],
) );

$choices = array( 'page'        => esc_html__( 'Page', 'yule' )	);
if ( yule_is_woocommerce_activated() ) {
	$choices['product'] = esc_html__( 'Product', 'yule' );
}

$wp_customize->add_control( 'yule_theme_options[popular_content_type]', array(
	'label'             => esc_html__( 'Content Type:', 'yule' ),
	'section'           => 'yule_popular_section',
	'type'				=> 'select',
	'active_callback' 	=> 'yule_is_popular_section_enable',
	'choices'			=> $choices,
) );

// Popular content type page control and setting
$wp_customize->add_setting( 'yule_theme_options[popular_content_type_page]', array(
	'sanitize_callback' => 'yule_sanitize_page',
) );

$wp_customize->add_control( 'yule_theme_options[popular_content_type_page]', array(
	'label'             => esc_html__( 'Select Page:', 'yule' ),
	'section'           => 'yule_popular_section',
	'type'				=> 'dropdown-pages',
	'active_callback' 	=> 'yule_is_popular_section_content_page_enable',
) );

if ( yule_is_woocommerce_activated() ) {
	$product_choices = array();
	$args = array(
		'post_type' => 'product',
		'posts_per_page' => -1
	);
	$loop = new WP_Query( $args );
	if ( $loop->have_posts() ) {
		while ( $loop->have_posts() ) : $loop->the_post();
			$id = get_the_ID();
			$title = get_the_title();
			$product_choices[ absint( $id ) ] = esc_html( $title );
		endwhile;
	}

	// Popular content type product control and setting
	$wp_customize->add_setting( 'yule_theme_options[popular_content_type_product]', array(
		'sanitize_callback' => 'yule_sanitize_select',
	) );

	$wp_customize->add_control( 'yule_theme_options[popular_content_type_product]', array(
		'label'             => esc_html__( 'Select Product:', 'yule' ),
		'section'           => 'yule_popular_section',
		'type'				=> 'select',
		'active_callback' 	=> 'yule_is_popular_section_content_product_enable',
		'choices'			=> $product_choices
	) );
}