<?php
/**
 * Yule custom helper funtions
 *
 * This is the template that includes all the other files for core featured of Photo Fusion Pro
 *
 * @package Theme Palace
 * @subpackage Yule
 * @since Yule 1.0.0
 */

if( ! function_exists( 'yule_check_enable_status' ) ):
	/**
	 * Check status of content.
	 *
	 * @since Yule 1.0.0
	 */
  	function yule_check_enable_status( $input, $content_enable ){
		$options = yule_get_theme_options();

		// Content status.
		$content_status = $options[ $content_enable ];

		if ( ( ! is_home() && is_front_page() ) && $content_status ) {
			$input = true;
		}
		else {
			$input = false;
		}
		
		return $input;
  	}
endif;
add_filter( 'yule_section_status', 'yule_check_enable_status', 10, 2 );


if ( ! function_exists( 'yule_is_sidebar_enable' ) ) :
	/**
	 * Check if sidebar is enabled in meta box first then in customizer
	 *
	 * @since Yule 1.0.0
	 */
	function yule_is_sidebar_enable() {
		$options               = yule_get_theme_options();

		$sidebar_position      = $options['sidebar_position'];
		$post_sidebar_position = '';

		if ( is_single() ) {
			$sidebar_position = $options['post_sidebar_position'];
		} elseif ( is_page() ) {
			$sidebar_position = $options['page_sidebar_position'];
		}
		
		if ( ! is_front_page() && is_home()  ) {
			$post_id = get_option( 'page_for_posts' );
			if ( ! empty( $post_id ) ){
				$post_sidebar_position = get_post_meta( $post_id, 'yule_sidebar_layout', true );
			} else {
				$post_sidebar_position = '';
			}
		} elseif ( is_archive() || is_search() ) {
			$post_sidebar_position = '';
		} else {
			$post_id = get_the_id();
			$post_sidebar_position = get_post_meta( $post_id, 'yule_sidebar_layout', true );
		}

		if ( ( $sidebar_position == 'no-sidebar' && $post_sidebar_position == "" ) || $post_sidebar_position == 'no-sidebar' ) {
			return false;
		} else {
			return true;
		}

	}
endif;


if ( ! function_exists( 'yule_is_frontpage_content_enable' ) ) :
	/**
	 * Check home page ( static ) content status.
	 *
	 * @param bool $status Home page content status.
	 * @return bool Modified home page content status.
	 */
	function yule_is_frontpage_content_enable( $status ) {
		if ( is_front_page() ) {
			$options = yule_get_theme_options();
			$front_page_content_status = $options['enable_frontpage_content'];
			if ( false === $front_page_content_status ) {
				$status = false;
			}
		}
		return $status;
	}

endif;

add_filter( 'yule_filter_frontpage_content_enable', 'yule_is_frontpage_content_enable' );


add_action( 'yule_action_pagination', 'yule_pagination', 10 );
if ( ! function_exists( 'yule_pagination' ) ) :

	/**
	 * pagination.
	 *
	 * @since Yule 1.0.0
	 */
	function yule_pagination() {
		$options = yule_get_theme_options();
		if ( true == $options['pagination_enable'] ) {
			$pagination = $options['pagination_type'];
			if ( $pagination == 'default' ) :
				the_posts_navigation( array(
				'prev_text'          => yule_get_svg( array( 'icon' => 'left' ) ) . '<span>' . esc_html__( 'Older', 'yule' ) . '</span>',
				'next_text'          => '<span>' . esc_html__( 'Newer', 'yule' ) . '</span>' . yule_get_svg( array( 'icon' => 'right' ) ),
			) );
			elseif ( $pagination == 'numeric' ) :
				the_posts_pagination( array(
				    'prev_text' => yule_get_svg( array( 'icon' => 'left' ) ) . '<span class="screen-reader-text">' . esc_html__( 'Previous Posts', 'yule' ) . '</span>',
				    'next_text' => '<span class="screen-reader-text">' . esc_html__( 'Next Posts', 'yule' ) . '</span>' . yule_get_svg( array( 'icon' => 'right' ) ),
				    'before_page_number' => '<span>',
				    'after_page_number' => '</span>'
				) );
			endif;
		}
	}

endif;


add_action( 'yule_action_post_pagination', 'yule_post_pagination', 10 );
if ( ! function_exists( 'yule_post_pagination' ) ) :

	/**
	 * post pagination.
	 *
	 * @since Yule 1.0.0
	 */
	function yule_post_pagination() {
		$options = yule_get_theme_options();
		if ( $options['pagination_enable'] ) {
		the_post_navigation( array(
				'prev_text'          => yule_get_svg( array( 'icon' => 'left' ) ) . '<span>%title</span>',
				'next_text'          => '<span>%title</span>' . yule_get_svg( array( 'icon' => 'right' ) ),
			) );
		}
	}
endif;


if ( ! function_exists( 'yule_excerpt_length' ) ) :
	/**
	 * long excerpt
	 * 
	 * @since Yule 1.0.0
	 * @return long excerpt value
	 */
	function yule_excerpt_length( $length ){
		if ( is_admin() ) {
			return $length;
		}

		$options = yule_get_theme_options();
		$length = $options['long_excerpt_length'];
		return $length;
	}
endif;
add_filter( 'excerpt_length', 'yule_excerpt_length', 999 );


if ( ! function_exists( 'yule_excerpt_more' ) ) :
	// Read more
	function yule_excerpt_more( $more ){
		if ( is_admin() ) {
			return $more;
		}

		return ' &hellip; ';
	}
endif;
add_filter( 'excerpt_more', 'yule_excerpt_more' );


if ( ! function_exists( 'yule_layout' ) ) :
	/**
	 * Check home page layout option
	 *
	 * @since Yule 1.0.0
	 *
	 * @return string Yule layout value
	 */
	function yule_layout() {
		$options = yule_get_theme_options();

		$sidebar_position      = $options['sidebar_position'];

		if ( is_single() ) {
			$sidebar_position = $options['post_sidebar_position'];
		} elseif ( is_page() ) {
			$sidebar_position = $options['page_sidebar_position'];
		}
		
		if ( ! is_front_page() && is_home()  ) {
			$post_id = get_option( 'page_for_posts' );
			if ( ! empty( $post_id ) ){
				$post_sidebar_position = get_post_meta( $post_id, 'yule_sidebar_layout', true );
			} else {
				$post_sidebar_position = '';
			}
		} elseif ( is_archive() || is_search() ) {
			$post_sidebar_position = '';
		} else {
			$post_id = get_the_id();
			$post_sidebar_position = get_post_meta( $post_id, 'yule_sidebar_layout', true );
		}

		if ( isset( $post_sidebar_position ) && ! empty( $post_sidebar_position ) ) {
				$sidebar_position = $post_sidebar_position;
			}

		return $sidebar_position;
	}
endif;

/**
 * Add SVG definitions to the footer.
 */
function yule_include_svg_icons() {
	// Define SVG sprite file.
	$svg_icons = get_template_directory() . '/assets/images/svg-icons.svg';

	// If it exists, include it.
	if ( file_exists( $svg_icons ) ) {
		require_once( $svg_icons );
	}
}
add_action( 'wp_footer', 'yule_include_svg_icons', 9999 );

/**
 * Return SVG markup.
 *
 * @param array $args {
 *     Parameters needed to display an SVG.
 *
 *     @type string $icon  Required SVG icon filename.
 *     @type string $title Optional SVG title.
 *     @type string $desc  Optional SVG description.
 * }
 * @return string SVG markup.
 */
function yule_get_svg( $args = array() ) {
	// Make sure $args are an array.
	if ( empty( $args ) ) {
		return esc_html__( 'Please define default parameters in the form of an array.', 'yule' );
	}

	// Define an icon.
	if ( false === array_key_exists( 'icon', $args ) ) {
		return esc_html__( 'Please define an SVG icon filename.', 'yule' );
	}

	// Set defaults.
	$defaults = array(
		'icon'        => '',
		'title'       => '',
		'desc'        => '',
		'fallback'    => false,
	);

	// Parse args.
	$args = wp_parse_args( $args, $defaults );

	// Set aria hidden.
	$aria_hidden = ' aria-hidden="true"';

	// Set ARIA.
	$aria_labelledby = '';

	/*
	 * Yule doesn't use the SVG title or description attributes; non-decorative icons are described with .screen-reader-text.
	 *
	 * However, child themes can use the title and description to add information to non-decorative SVG icons to improve accessibility.
	 *
	 * Example 1 with title: <?php echo yule_get_svg( array( 'icon' => 'arrow-right', 'title' => __( 'This is the title', 'textdomain' ) ) ); ?>
	 *
	 * Example 2 with title and description: <?php echo yule_get_svg( array( 'icon' => 'arrow-right', 'title' => __( 'This is the title', 'textdomain' ), 'desc' => __( 'This is the description', 'textdomain' ) ) ); ?>
	 *
	 * See https://www.paciellogroup.com/blog/2013/12/using-aria-enhance-svg-accessibility/.
	 */
	if ( $args['title'] ) {
		$aria_hidden     = '';
		$unique_id       = uniqid();
		$aria_labelledby = ' aria-labelledby="title-' . esc_attr( $unique_id ) . '"';

		if ( $args['desc'] ) {
			$aria_labelledby = ' aria-labelledby="title-' . esc_attr( $unique_id ) . ' desc-' . esc_attr( $unique_id ) . '"';
		}
	}

	// Begin SVG markup.
	$svg = '<svg class="icon icon-' . esc_attr( $args['icon'] ) . '"' . $aria_hidden . $aria_labelledby . ' role="img">';

	// Display the title.
	if ( $args['title'] ) {
		$svg .= '<title id="title-' . esc_attr( $unique_id ) . '">' . esc_html( $args['title'] ) . '</title>';

		// Display the desc only if the title is already set.
		if ( $args['desc'] ) {
			$svg .= '<desc id="desc-' . esc_attr( $unique_id ) . '">' . esc_html( $args['desc'] ) . '</desc>';
		}
	}

	/*
	 * Display the icon.
	 *
	 * The whitespace around `<use>` is intentional - it is a work around to a keyboard navigation bug in Safari 10.
	 *
	 * See https://core.trac.wordpress.org/ticket/38387.
	 */
	$svg .= ' <use href="#icon-' . esc_html( $args['icon'] ) . '" xlink:href="#icon-' . esc_html( $args['icon'] ) . '"></use> ';

	// Add some markup to use as a fallback for browsers that do not support SVGs.
	if ( $args['fallback'] ) {
		$svg .= '<span class="svg-fallback icon-' . esc_attr( $args['icon'] ) . '"></span>';
	}

	$svg .= '</svg>';

	return $svg;
}

/**
 * Add dropdown icon if menu item has children.
 *
 * @param  string $title The menu item's title.
 * @param  object $item  The current menu item.
 * @param  array  $args  An array of wp_nav_menu() arguments.
 * @param  int    $depth Depth of menu item. Used for padding.
 * @return string $title The menu item's title with dropdown icon.
 */
function yule_dropdown_icon_to_menu_link( $title, $item, $args, $depth ) {
	if ( 'primary' === $args->theme_location ) {
		foreach ( $item->classes as $value ) {
			if ( 'menu-item-has-children' === $value || 'page_item_has_children' === $value ) {
				$title = $title . yule_get_svg( array( 'icon' => 'down' ) );
			}
		}
	}

	return $title;
}
add_filter( 'nav_menu_item_title', 'yule_dropdown_icon_to_menu_link', 10, 4 );

/**
 * Returns an array of supported social links (URL and icon name).
 *
 * @return array $social_links_icons
 */
function yule_social_links_icons() {
	// Supported social links icons.
	$social_links_icons = array(
		'behance.net'     => 'behance',
		'codepen.io'      => 'codepen',
		'deviantart.com'  => 'deviantart',
		'digg.com'        => 'digg',
		'dribbble.com'    => 'dribbble',
		'dropbox.com'     => 'dropbox',
		'facebook.com'    => 'facebook',
		'flickr.com'      => 'flickr',
		'foursquare.com'  => 'foursquare',
		'plus.google.com' => 'google-plus',
		'github.com'      => 'github',
		'instagram.com'   => 'instagram',
		'linkedin.com'    => 'linkedin',
		'mailto:'         => 'envelope-o',
		'medium.com'      => 'medium',
		'pinterest.com'   => 'pinterest-p',
		'getpocket.com'   => 'get-pocket',
		'reddit.com'      => 'reddit-alien',
		'skype.com'       => 'skype',
		'skype:'          => 'skype',
		'slideshare.net'  => 'slideshare',
		'snapchat.com'    => 'snapchat-ghost',
		'soundcloud.com'  => 'soundcloud',
		'spotify.com'     => 'spotify',
		'stumbleupon.com' => 'stumbleupon',
		'tumblr.com'      => 'tumblr',
		'twitch.tv'       => 'twitch',
		'twitter.com'     => 'twitter',
		'vimeo.com'       => 'vimeo',
		'vine.co'         => 'vine',
		'vk.com'          => 'vk',
		'wordpress.org'   => 'wordpress',
		'wordpress.com'   => 'wordpress',
		'yelp.com'        => 'yelp',
		'youtube.com'     => 'youtube',
	);

	/**
	 * Filter Yule social links icons.
	 *
	 * @since Yule 1.0.0
	 *
	 * @param array $social_links_icons Array of social links icons.
	 */
	return apply_filters( 'yule_social_links_icons', $social_links_icons );
}

/**
 * Display SVG icons in social links menu.
 *
 * @param  string  $item_output The menu item output.
 * @param  WP_Post $item        Menu item object.
 * @param  int     $depth       Depth of the menu.
 * @param  array   $args        wp_nav_menu() arguments.
 * @return string  $item_output The menu item output with social icon.
 */
function yule_nav_menu_social_icons( $item_output, $item, $depth, $args ) {
	// Get supported social icons.
	$social_icons = yule_social_links_icons();

	// Change SVG icon inside social links menu if there is supported URL.
	if ( 'social' === $args->theme_location ) {
		foreach ( $social_icons as $attr => $value ) {
			if ( false !== strpos( $item_output, $attr ) ) {
				$item_output = str_replace( $args->link_after, '</span>' . yule_get_svg( array( 'icon' => esc_attr( $value ) ) ), $item_output );
			}
		}
	}

	return $item_output;
}
add_filter( 'walker_nav_menu_start_el', 'yule_nav_menu_social_icons', 10, 4 );

/**
 * Fallback function call for menu
 * @param  Mixed $args Menu arguments
 * @return String $output Return or echo the add menu link.       
 */
function yule_menu_fallback_cb( $args ){
    if ( ! current_user_can( 'edit_theme_options' ) ){
	    return;
   	}
    // see wp-includes/nav-menu-template.php for available arguments
    $link = $args['link_before']
        	. '<a href="' .esc_url( admin_url( 'nav-menus.php' ) ) . '">' . $args['before'] . esc_html__( 'Add a menu','yule' ) . $args['after'] . '</a>'
        	. $args['link_after'];

   	if ( FALSE !== stripos( $args['items_wrap'], '<ul' ) || FALSE !== stripos( $args['items_wrap'], '<ol' )
	){
		$link = "<li>$link</li>";
	}
	$output = sprintf( $args['items_wrap'], $args['menu_id'], $args['menu_class'], $link );
	if ( ! empty ( $args['container'] ) ){
		$output = sprintf( '<%1$s class="%2$s" id="%3$s">%4$s</%1$s>', $args['container'], $args['container_class'], $args['container_id'], $output );
	}
	if ( $args['echo'] ){
		echo $output;
	}
	return $output;
}

/**
 * Function to detect SCRIPT_DEBUG on and off.
 * @return string If on, empty else return .min string.
 */
function yule_min() {
	return defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
}

/**
 * Display SVG icons as per the link.
 *
 * @param  string   $social_link        Theme mod value rendered
 * @return string  SVG icon HTML
 */
function yule_return_social_icon( $social_link ) {
	// Get supported social icons.
	$social_icons = yule_social_links_icons();

	// Check in the URL for the url in the array.
	foreach ( $social_icons as $attr => $value ) {
		if ( false !== strpos( $social_link, $attr ) ) {
			return yule_get_svg( array( 'icon' => esc_attr( $value ) ) );
		}
	}
}

/**
 * Checks to see if we're on the homepage or not.
 */
function yule_is_frontpage() {
	return ( is_front_page() && ! is_home() );
}

/**
 * Checks to see if Static Front Page is set to "Your latest posts".
 */
function yule_is_latest_posts() {
	return ( is_front_page() && is_home() );
}

/**
 * Checks to see if Static Front Page is set to "A static page" and Posts page.
 */
function yule_is_posts_page() {
	return ( is_home() && ! is_front_page() );
}

if ( ! function_exists( 'yule_is_woocommerce_activated' ) ) {
	/**
	 * Check if WooCommerce is activated.
	 * @return [type] [description]
	 */
	function yule_is_woocommerce_activated() {
		if ( class_exists( 'WooCommerce' ) ) { 
			return true; 
		} else { 
			return false; 
		}
	}
}

if ( ! function_exists( 'yule_is_woocommerce' ) ) {
	/**
	 * Check if the page is WooCommerce page along with cart, account, checkout.
	 * @return Bool True on woocommerce pages.
	 */
	function yule_is_woocommerce() {
		if ( yule_is_woocommerce_activated() ) {
			if ( is_woocommerce() || is_cart() || is_checkout() || is_account_page() ) { 
				return true; 
			} else { 
				return false; 
			}
		}
	}
}